@@ -5,23 +5,6 @@ use Moose;
 use PRANG::Graph;
 use XML::SRS::Contact::Address;
 use XML::SRS::Contact::PSTN;
-use XML::SRS::Types;
-
-# handles
-has_attr 'handle_id' =>
-	is => "ro",
-	isa => "XML::SRS::HandleId",
-	xml_name => "HandleId",
-	predicate => "has_handle_id",
-	;
-
-has_attr 'action_id' =>
-	is => "rw",
-	isa => "XML::SRS::UID",
-	xml_name => 'ActionId',
-	xml_required => 0,
-	predicate => "has_action_id",
-	;
 
 # attributes
 has_attr 'name' =>
@@ -33,7 +16,7 @@ has_attr 'name' =>
 
 has_attr 'email' =>
 	is => "ro",
-	isa => "XML::SRS::Email",
+	isa => "Str",
 	xml_name => "Email",
 	predicate => "has_email",
 	;
@@ -45,7 +28,6 @@ has_element 'address' =>
 	xml_nodeName => "PostalAddress",
 	predicate => "has_address",
 	coerce => 1,
-	xml_required => 0,
 	;
 
 has_element 'phone' =>
@@ -54,7 +36,6 @@ has_element 'phone' =>
 	predicate => "has_phone",
 	xml_nodeName => "Phone",
 	coerce => 1,
-	xml_required => 0,
 	;
 
 has_element 'fax' =>
@@ -63,7 +44,6 @@ has_element 'fax' =>
 	predicate => "has_fax",
 	xml_nodeName => "Fax",
 	coerce => 1,
-	xml_required => 0,
 	;
 
 with 'XML::SRS::Node';
