@@ -27,15 +27,11 @@ has_attr 'subscriber' =>
 
 with 'XML::SRS::Node';
 
+# a coerce from Str would be nice, but need to figure out how best to
+# turn random strings into the above three components.
 use Moose::Util::TypeConstraints;
 coerce __PACKAGE__
 	=> from "HashRef"
 	=> via { __PACKAGE__->new( %$_ ); };
 
-# a coerce from Str will only handle strings in the format
-# defined in the EPP specification ()
-coerce __PACKAGE__
-	=> from "Str"
-	=> via { $_ =~ m/^\+(\d{1,3})\.(\d+)$/; __PACKAGE__->new(cc=>$1,ndc=>'',subscriber=>$2); };
-
 1;
