@@ -7,42 +7,35 @@ use Moose::Util::TypeConstraints;
 
 sub root_element { "Error" }
 
-has_attr "error_id" =>
+has_attr "ErrorId" =>
 	is => "ro",
 	isa => "XML::SRS::UID",
 	required => 1,
-	xml_name => "ErrorId",
 	;
 
 enum "XML::SRS::Error::Severity" =>
-	qw( alert crit err );
+	qw( emergency alert critical error err warning notice info );
 
-has_attr "severity" =>
+has_attr "Severity" =>
 	is => "ro",
 	isa => "XML::SRS::Error::Severity",
 	required => 1,
-	xml_name => "Severity",
 	;
 
-has_attr "hint" =>
+has_attr "Hint" =>
 	is => "ro",
 	isa => "XML::SRS::UID",  # odd
 	required => 1,
-	xml_name => "Hint",
 	;
 
-has_element "desc" =>
+has_element "Description" =>
 	is => "ro",
 	isa => "Str",
-	xml_nodeName => "Description",
 	;
 
-has_element "details" =>
+has_element "ErrorDetails" =>
 	is => "ro",
 	isa => "ArrayRef[Str]",
-	xml_min => 0,
-	xml_nodeName => "ErrorDetails",
-	auto_deref => 1,
 	;
 
 with 'XML::SRS::ActionResponse';
